******------------------------------------------------------------------
*     This subroutine defines the discretized version of the priori
*     believes, based on the beta parameters.
******------------------------------------------------------------------
      SUBROUTINE INITIALIZE

******------------------------------------------------------------------
*     Double precision everything.
******------------------------------------------------------------------
      implicit double precision (a-h,o-z)

******------------------------------------------------------------------
*     Include files with parameters and common blocks.
******------------------------------------------------------------------
      include 'fp_def.f'
      include 'cb_all.f'

******------------------------------------------------------------------
*     Estimate beta parameters for priori distributions; ep, del and hon
*     only, p is a discrete variable.
******------------------------------------------------------------------
      epa = (epav**2)*(1-epav)/((epstd**2)*(1+epav))
      epb = epa*(1-epav)/epav
      dela = (delav**2)*(1-delav)/((delstd**2)*(1+delav))
      delb = dela*(1-delav)/delav
      hona = (honav**2)*(1-honav)/((honstd**2)*(1+honav));
      honb = hona*(1-honav)/honav;
******------------------------------------------------------------------
*     Initialize hypercube counters
******------------------------------------------------------------------
      irand=1
      jrand=1

******------------------------------------------------------------------
*     Initialize opinion field
******------------------------------------------------------------------
      sumphi=0.0d0
      do i=0,1
         p=dfloat(1-i)*(1-pav)+dfloat(i)*pav
         do j=0,md
            ep=dfloat(j)/dfloat(md)
            if (ep.eq.0) then
               betaep=0.0d0
            else
               betaep =(ep**(epa-1))*((1-ep)**(epb-1))
            end if
            if(betaep.eq.NAN) betaep=0.0d0

            do k=0,md
               del=dfloat(k)/dfloat(md)
               if (del.eq.0) then
                  betadel =0.0d0
               else
                  betadel =(del**(dela-1))*((1-del)**(delb-1))
               end if
               if(betadel.eq.NAN) betadel=0.0d0

               do l=0,md
                  hon=dfloat(l)/dfloat(md)
                  if (hon.eq.0) then
                     betahon=0.0d0
                  else
                     betahon =(hon**(hona-1))*((1-hon)**(honb-1))
                  end if
                  if(betahon.eq.NAN) betahon=0.0d0
                  
                  phi(i,j,k,l)=p*betaep*betadel*betahon
                  sumphi=sumphi+phi(i,j,k,l)
               end do
            end do
         end do
      end do

******------------------------------------------------------------------
*     Normalize the opinion field.
******------------------------------------------------------------------
      sumphi=1.0d0/sumphi
      do i=0,1
         do j=0,md
            do k=0,md
               do l=1,md
                  phi(i,j,k,l)=sumphi*phi(i,j,k,l)
               end do
            end do
         end do
      end do

******------------------------------------------------------------------
*     Calculate initial averages.
******------------------------------------------------------------------
      pave=0.0d0
      epave=0.0d0
      delave=0.0d0
      honave=0.0d0


      do i=0,1
         p=dfloat(i)
         do j=0,md
            eps=dfloat(j)/dfloat(md)
            do k=0,md
               del=dfloat(k)/dfloat(md)
               do l=0,md
                  hon=dfloat(l)/dfloat(md)

                  pave=pave+p*phi(i,j,k,l)
                  epave=epave+eps*phi(i,j,k,l)
                  delave=delave+del*phi(i,j,k,l)
                  honave=honave+hon*phi(i,j,k,l)

               end do
            end do
         end do
      end do

******------------------------------------------------------------------
      return
      END
******------------------------------------------------------------------
